# PAL kit

This is a collection of useful functions for code that we write in our group.

## Install

Run
```
pip install palkit
```

or install directly from GitHub:
```
pip install git+https://github.com/predictive-analytics-lab/palkit.git@main
```
